﻿using System;
using System.ComponentModel;
using System.Runtime.CompilerServices;

namespace FaxToBinary
{
	public class ViewModelBase : INotifyPropertyChanged
	{
		public event PropertyChangedEventHandler PropertyChanged;

		protected void OnPropertyChanged([CallerMemberName] string propertyName = "")
		{
			PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
		}

		protected void SetProperty<T>(ref T propertyStore, T newValue, Action<T, T> onChangedHandler = null, [CallerMemberName] string propertyName = null)
		{
			if (!Equals(propertyStore, newValue))
			{
				T oldValue = propertyStore;
				propertyStore = newValue;
				OnPropertyChanged(propertyName);
				onChangedHandler?.Invoke(oldValue, newValue);
			}
		}
	}
}
